@@ -17,7 +17,7 @@ class ArticleIndex(ListView):
         Add published queryset to the context
         """
         context = super().get_context_data(
-            object_list=Article.objects.published(), **kwargs
+            object_list=Article.objects.published(user=self.request.user), **kwargs
         )
         return context
 
@@ -27,5 +27,12 @@ class ArticleDetail(DetailView):
     Detail view for an news object
     """
 
-    queryset = Article.objects.published()
     template_name = "./news_detail.html"
+
+    def get_queryset(self):
+        """
+        Override the default queryset method so that we can access the request.user
+        """
+        if self.queryset is None:
+            return Article.objects.published(user=self.request.user)
+        return self.queryset
